# Interpretation

Sequence interpretation tools (like in silico mutagenesis).

## ISM

``` {eval-rst}
.. module:: alphagenome.interpretation
.. currentmodule:: alphagenome

.. autosummary::
    :toctree: generated

    interpretation.ism.ism_variants
    interpretation.ism.ism_matrix
```
